@@ -22,7 +22,9 @@
 
 /// @cond Doxygen_Suppress
 
-#ifdef __CUDACC__
+// If CUDA or HIP (AMD's Heterogeneous-computing Interface for
+// Portability), use the thrust complex library 
+#if defined(__CUDACC__) || defined(__HIP__)
 #    include <thrust/complex.h>
 #    define COMPLEX_NAMESPACE thrust
 #else
@@ -40,7 +42,8 @@ IMATH_INTERNAL_NAMESPACE_HEADER_ENTER
 ///
 /// @return 1 if the equation has a solution, 0 if there is no
 /// solution, and -1 if all real numbers are solutions.
-template <class T> IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveLinear (T a, T b, T& x);
+template <class T>
+IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveLinear (T a, T b, T& x);
 
 ///
 /// Solve for x in the quadratic equation:
@@ -50,7 +53,8 @@ template <class T> IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveLinear (T a, T b,
 /// @return 2 if the equation has two solutions, 1 if the equation has
 /// a single solution, 0 if there is no solution, and -1 if all real
 /// numbers are solutions.
-template <class T> IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveQuadratic (T a, T b, T c, T x[2]);
+template <class T>
+IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveQuadratic (T a, T b, T c, T x[2]);
 template <class T>
 
 ///
@@ -64,7 +68,8 @@ template <class T>
 ///
 /// @return 0 if there is no solution, and -1 if all real
 /// numbers are solutions, otherwise return the number of solutions.
-IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveNormalizedCubic (T r, T s, T t, T x[3]);
+IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int
+solveNormalizedCubic (T r, T s, T t, T x[3]);
 
 ///
 /// Solve for x in the cubic equation:
@@ -77,7 +82,8 @@ IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveNormalizedCubic (T r, T s, T t, T x[
 ///
 /// @return 0 if there is no solution, and -1 if all real
 /// numbers are solutions, otherwise return the number of solutions.
-template <class T> IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveCubic (T a, T b, T c, T d, T x[3]);
+template <class T>
+IMATH_HOSTDEVICE IMATH_CONSTEXPR14 int solveCubic (T a, T b, T c, T d, T x[3]);
 
 //---------------
 // Implementation
@@ -106,10 +112,7 @@ template <class T>
 IMATH_CONSTEXPR14 int
 solveQuadratic (T a, T b, T c, T x[2])
 {
-    if (a == 0)
-    {
-        return solveLinear (b, c, x[0]);
-    }
+    if (a == 0) { return solveLinear (b, c, x[0]); }
     else
     {
         T D = b * b - 4 * a * c;
@@ -156,7 +159,7 @@ solveNormalizedCubic (T r, T s, T t, T x[3])
     if (D > 0)
     {
         auto real_root = [] (T a, T x) -> T {
-            T sign = std::copysign(T(1), a);
+            T sign = std::copysign (T (1), a);
             return sign * std::pow (sign * a, T (1) / x);
         };
 
@@ -167,27 +170,30 @@ solveNormalizedCubic (T r, T s, T t, T x[3])
         return 1;
     }
 
-    namespace CN     = COMPLEX_NAMESPACE;
-    CN::complex<T> u = CN::pow (-q / 2 + CN::sqrt (CN::complex<T> (D)), T (1) / T (3));
+    namespace CN = COMPLEX_NAMESPACE;
+    CN::complex<T> u =
+        CN::pow (-q / 2 + CN::sqrt (CN::complex<T> (D)), T (1) / T (3));
     CN::complex<T> v = -p / (T (3) * u);
 
     const T sqrt3 = T (1.73205080756887729352744634150587); // enough digits
                                                             // for long double
     CN::complex<T> y0 (u + v);
-    CN::complex<T> y1 (-(u + v) / T (2) + (u - v) / T (2) * CN::complex<T> (0, sqrt3));
-    CN::complex<T> y2 (-(u + v) / T (2) - (u - v) / T (2) * CN::complex<T> (0, sqrt3));
+    CN::complex<T> y1 (
+        -(u + v) / T (2) + (u - v) / T (2) * CN::complex<T> (0, sqrt3));
+    CN::complex<T> y2 (
+        -(u + v) / T (2) - (u - v) / T (2) * CN::complex<T> (0, sqrt3));
 
     if (D == 0)
     {
-        x[0] = y0.real() - r / 3;
-        x[1] = y1.real() - r / 3;
+        x[0] = y0.real () - r / 3;
+        x[1] = y1.real () - r / 3;
         return 2;
     }
     else
     {
-        x[0] = y0.real() - r / 3;
-        x[1] = y1.real() - r / 3;
-        x[2] = y2.real() - r / 3;
+        x[0] = y0.real () - r / 3;
+        x[1] = y1.real () - r / 3;
+        x[2] = y2.real () - r / 3;
         return 3;
     }
 }
@@ -196,10 +202,7 @@ template <class T>
 IMATH_CONSTEXPR14 int
 solveCubic (T a, T b, T c, T d, T x[3])
 {
-    if (a == 0)
-    {
-        return solveQuadratic (b, c, d, x);
-    }
+    if (a == 0) { return solveQuadratic (b, c, d, x); }
     else
     {
         return solveNormalizedCubic (b / a, c / a, d / a, x);
